@@ -17,9 +17,15 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include "globals.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include <math.h>
+#include "appdata.h"
 #include "basic_stats.h"
 #include "ui_utils.h"
+#include "util.h"
 
 static long packet_list_item_n = 0;
 
@@ -56,6 +62,27 @@ substract_times (struct timeval a, struct timeval b)
   return result;
 }				/* substract_times */
 
+/* returns the time difference a-b expressed in ms */
+double substract_times_ms (const struct timeval *a, const struct timeval *b)
+{
+  double result;
+
+  result = (a->tv_sec - b->tv_sec) * 1000.0 + (a->tv_usec - b->tv_usec) / 1000.0;
+
+#if CHECK_EXPIRATION
+  {
+    struct timeval t = substract_times(*a, *b);
+    double ck = (double)(t.tv_sec*1000.0 + t.tv_usec/1000.0);
+    if (fabs(ck - result) > 0.000001)
+      g_warning("Errore substract_times_ms: ms: %.f, timeval: %.f, delta: %.10f", 
+                result, ck, fabs(ck-result));
+  }
+#endif
+
+  return result;
+}
+
+
 
 /***************************************************************************
  *
@@ -154,7 +181,7 @@ void packet_list_item_delete(packet_list_item_t *pli)
               pli->info = NULL;
 
               /* global packet stats */
-              total_mem_packets--;
+              appdata.total_mem_packets--;
             }
         }
     
@@ -177,7 +204,7 @@ void basic_stats_reset(basic_stats_t *tf_stat)
   tf_stat->accumulated = 0;
   tf_stat->avg_size = 0;
   tf_stat->accu_packets = 0;
-  tf_stat->last_time = now;
+  tf_stat->last_time = appdata.now;
 }
 
 void basic_stats_add(basic_stats_t *tf_stat, gdouble val)
@@ -187,7 +214,7 @@ void basic_stats_add(basic_stats_t *tf_stat, gdouble val)
   tf_stat->aver_accu += val;
   ++tf_stat->accu_packets;
   tf_stat->avg_size = tf_stat->accumulated / tf_stat->accu_packets;
-  tf_stat->last_time = now;
+  tf_stat->last_time = appdata.now;
   /* averages are calculated by basic_stats_avg */
 }
 
@@ -232,3 +259,27 @@ gchar *basic_stats_dump(const basic_stats_t *tf_stat)
   return msg;
 }
 
+/* returns a newly allocated string with an xml dump of the stats */
+gchar *basic_stats_xml(const basic_stats_t *tf_stat)
+{
+  gchar *msg;
+  double diffms;
+
+  if (!tf_stat)
+    return xmltag("stats", "");
+
+  diffms = substract_times_ms(&appdata.now, &tf_stat->last_time);
+  msg = xmltag("stats",
+               "\n<avg>%.0f</avg>\n"
+               "<total>%.0f</total>\n"
+               "<avg_size>%.0f</avg_size>\n"
+               "<packets>%lu</packets>\n"
+               "<last_heard>%f</last_heard>\n",
+                        tf_stat->average,
+                        tf_stat->accumulated,
+                        tf_stat->avg_size,
+                        tf_stat->accu_packets,
+                        diffms / 1000.0 );
+  return msg;
+}
+
