@@ -27,6 +27,9 @@
  * other timevals. result = a - b */
 struct timeval substract_times (struct timeval a, struct timeval b);
 
+/* returns the time difference a-b expressed in ms */
+double substract_times_ms (const struct timeval *a, const struct timeval *b);
+
 typedef struct
 {
   gdouble average;		/* Average bytes in or out in the last x ms */
@@ -42,5 +45,6 @@ void basic_stats_add(basic_stats_t *tf_stat, gdouble val);
 void basic_stats_sub(basic_stats_t *tf_stat, gdouble val); 
 void basic_stats_avg(basic_stats_t *tf_stat, gdouble avg_msecs);
 gchar *basic_stats_dump(const basic_stats_t *tf_stat);
+gchar *basic_stats_xml(const basic_stats_t *tf_stat);
 
 #endif
