@@ -17,13 +17,15 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <gnome.h>
-#include "globals.h"
+#include "appdata.h"
 #include "callbacks.h"
 #include "diagram.h"
-
-/* Extern functions */
-extern void save_config (gchar * prefix);
+#include "preferences.h"
 
 void
 on_canvas1_size_allocate (GtkWidget * widget,
@@ -37,7 +39,7 @@ on_canvas1_size_allocate (GtkWidget * widget,
 				  widget->allocation.width / 2,
 				  widget->allocation.height / 2);
   ask_reposition(FALSE);
-  canvas = glade_xml_get_widget (xml, "canvas1");
+  canvas = glade_xml_get_widget (appdata.xml, "canvas1");
   update_diagram (canvas);
 }
 
