@@ -18,21 +18,33 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <gnome.h>
 #include <ctype.h>
 #include <netinet/in.h>
 #include <pcap.h>
 
-#include "globals.h"
+#include "appdata.h"
 #include "capture.h"
 #include "names.h"
+#include "links.h"
 #include "conversations.h"
 #include "dns.h"
 #include "decode_proto.h"
 #include "protocols.h"
+#include "preferences.h"
+#include "export.h"
 
 #define MAXSIZE 200
+
+#ifdef DISABLE_GDKINPUTADD
+#define PCAP_TIMEOUT 10
+#else
 #define PCAP_TIMEOUT 250
+#endif
 
 static pcap_t *pch_struct;		/* pcap structure */
 static gint pcap_fd;			/* The file descriptor used by libpcap */
@@ -45,8 +57,10 @@ static enum status_t capture_status = STOP;
 
 /* Local funtions declarations */
 static guint get_offline_packet (void);
-static void cap_t_o_destroy (gpointer data);
-static void read_packet_live(gpointer dummy, gint source,
+static void cap_t_o_destroy(gpointer data);
+static guint get_live_packet (void);
+static void live_timeout(gpointer data);
+static void gdk_input_callback(gpointer dummy, gint source,
 			 GdkInputCondition condition);
 
 
@@ -67,8 +81,8 @@ enum status_t get_capture_status(void)
 gchar *init_capture (void)
 {
   gchar *device;
-  gchar ebuf[300];
-  int linktype;		/* Type of device we are listening to */
+  gchar ebuf[PCAP_ERRBUF_SIZE];
+  unsigned int linktype;		/* Type of device we are listening to */
   static gchar errorbuf[300];
   static gboolean data_initialized = FALSE;
 
@@ -85,8 +99,8 @@ gchar *init_capture (void)
       data_initialized = TRUE;
     }
 
-  device = pref.interface;
-  if (!device && !pref.input_file)
+  device = appdata.interface;
+  if (!device && !appdata.input_file)
     {
       *ebuf = '\0'; /* reset error buffer before calling pcap functions */
       device = g_strdup (pcap_lookupdev (ebuf));
@@ -96,18 +110,19 @@ gchar *init_capture (void)
                     _("No capture device found or insufficient privileges.\n"
                       "Only file replay will be available.\n"
                       "EtherApe must be run with administrative privileges "
-                      "(e.g. root) to enable live capture."));
+                      "(e.g. root) to enable live capture.\n"
+                      "Pcap error: %s"), ebuf);
 	  return errorbuf;
 	}
       /* TODO I should probably tidy this up, I probably don't
        * need the local variable device. But I need to reset 
        * interface since I need to know whether we are in
        * online or offline mode later on */
-      pref.interface = device;
+      appdata.interface = device;
     }
 
 
-  if (!pref.input_file)
+  if (!appdata.input_file)
     {
       *ebuf = '\0'; /* reset error buffer before calling pcap functions */
       if (!
@@ -129,37 +144,57 @@ gchar *init_capture (void)
 	{
 	  snprintf (errorbuf, sizeof(errorbuf),
 		   _("Can't open both %s and device %s. Please choose one."),
-		   pref.input_file, device);
+		   appdata.input_file, device);
 	  return errorbuf;
 	}
       *ebuf = '\0'; /* reset error buffer before calling pcap functions */
-      if (!(pch_struct = pcap_open_offline (pref.input_file, ebuf)))
+      if (!(pch_struct = pcap_open_offline (appdata.input_file, ebuf)))
 	{
 	  snprintf (errorbuf, sizeof(errorbuf), 
-                  _("Error opening %s : %s"), pref.input_file, ebuf);
+                  _("Error opening %s : %s"), appdata.input_file, ebuf);
 	  return errorbuf;
 	}
-      g_my_info (_("%s opened for offline capture"), pref.input_file);
+      g_my_info (_("%s opened for offline capture"), appdata.input_file);
 
     }
 
   linktype = pcap_datalink(pch_struct);
   if (!setup_link_type(linktype))
     {
-        snprintf (errorbuf, sizeof(errorbuf), _("Link type %d not supported"), 
-                  linktype);
+      if (appdata.input_file)
+        {
+          snprintf (errorbuf, sizeof(errorbuf), 
+                    _("File %s contains packets with unsupported "
+                      "link type %d, cannot replay"), 
+                    appdata.input_file,
+                    linktype);
+        }
+      else if (device)
+        {
+          snprintf (errorbuf, sizeof(errorbuf), 
+                    _("Device %s uses unsupported link type %d,"
+                      "cannot capture. Please choose another interface."), 
+                    device,
+                    linktype);
+        }
+      else
+        {
+          snprintf (errorbuf, sizeof(errorbuf), _("Unsupported link type %d"), 
+                    linktype);
+        }
         return errorbuf;
     }
   
-  if (pref.mode == APEMODE_DEFAULT)
+  if (appdata.mode == APEMODE_DEFAULT)
     {
-      pref.mode = IP;
+      appdata.mode = IP;
       g_free (pref.filter);
-      pref.filter = get_default_filter(pref.mode);
+      pref.filter = get_default_filter(appdata.mode);
     }
-  if (pref.mode == LINK6 && !has_linklevel())
+  if (appdata.mode == LINK6 && !has_linklevel())
     {
-      snprintf (errorbuf, sizeof(errorbuf), _("Mode not available in this device"));
+      snprintf (errorbuf, sizeof(errorbuf), _("This device does not support link-layer mode. "
+                                              "Please use IP or TCP modes."));
       return errorbuf;
     }
 
@@ -176,7 +211,7 @@ set_filter (gchar * filter_string, gchar * device)
 {
   gchar ebuf[300];
   bpf_u_int32 netnum;
-  bpf_u_int32 netmask;
+  bpf_u_int32 netmask = 0;
   struct bpf_program fp;
 
   if (!pch_struct)
@@ -192,9 +227,11 @@ set_filter (gchar * filter_string, gchar * device)
       netmask = 0;
     }
   if (pcap_compile (pch_struct, &fp, filter_string, 1, netmask) < 0)
-    g_warning (_("Unable to parse filter string (%s)."), pcap_geterr (pch_struct));
+    g_warning (_("Unable to parse filter string (%s). Filter ignored."), 
+               pcap_geterr (pch_struct));
   else if (pcap_setfilter (pch_struct, &fp) < 0)
-    g_warning (_("Can't install filter (%s)."), pcap_geterr (pch_struct));
+    g_warning (_("Can't install filter (%s). Filter ignored."), 
+               pcap_geterr (pch_struct));
 
   return 0;
 }				/* set_filter */
@@ -213,6 +250,8 @@ gchar *get_default_filter (apemode_t mode)
     case LINK6:
       return g_strdup ("");
       break;
+    default:
+      break;
     }
   g_error("Invalid apemode %d", mode);
 }
@@ -239,14 +278,26 @@ start_capture (void)
    * See pause_capture for an explanation of why we don't always
    * add the source
    */
-  if (pref.interface && (capture_status == STOP))
+  if (appdata.interface && (capture_status == STOP))
     {
       g_my_debug (_("Starting live capture"));
+#ifdef DISABLE_GDKINPUTADD
+      /* disabled fd - always use timers */
+      capture_source = g_timeout_add_full (G_PRIORITY_DEFAULT,
+					   1,
+					   (GtkFunction) get_live_packet,
+					   NULL,
+					   (GDestroyNotify) live_timeout);
+      g_my_info(_("Using timers for live capture"));
+#else
+      /* default: use the fd obtained from pcap to optimize readings */
       capture_source = gdk_input_add (pcap_fd,
 				      GDK_INPUT_READ,
-				      (GdkInputFunction) read_packet_live, NULL);
+				      (GdkInputFunction)gdk_input_callback, 
+                                      NULL);
+#endif
     }
-  else if (!pref.interface)
+  else if (!appdata.interface)
     {
       g_my_debug (_("Starting offline capture"));
       capture_source = g_timeout_add_full (G_PRIORITY_DEFAULT,
@@ -257,7 +308,7 @@ start_capture (void)
     }
 
   /* set the antialiasing */
-  gc = GNOME_CANVAS (glade_xml_get_widget (xml, "canvas1"));
+  gc = GNOME_CANVAS (glade_xml_get_widget (appdata.xml, "canvas1"));
   if (gc)
     gc->aa = TRUE;
 
@@ -271,7 +322,7 @@ pause_capture (void)
   if (capture_status != PLAY)
     return TRUE;
 
-  if (!pref.interface)
+  if (!appdata.interface)
     {
       g_my_debug (_("Pausing offline capture"));
       if (!g_source_remove (capture_source))
@@ -294,7 +345,7 @@ stop_capture (void)
   if (capture_status == STOP)
       return TRUE;
 
-  if (pref.interface)
+  if (appdata.interface)
     {
       g_my_debug (_("Stopping live capture"));
       gdk_input_remove (capture_source);	/* gdk_input_remove does not
@@ -315,15 +366,15 @@ stop_capture (void)
   new_nodes_clear();
 
   /* Clean the buffer */
-  if (!pref.interface)
+  if (!appdata.interface)
     get_offline_packet ();
 
   /* Close the capture */
   pcap_stats (pch_struct, &ps);
-  g_my_debug ("libpcap received %d packets, dropped %d. EtherApe saw %lu",
-	      ps.ps_recv, ps.ps_drop, n_packets);
+  g_my_info("libpcap received %d packets, dropped %d. EtherApe saw %lu",
+	      ps.ps_recv, ps.ps_drop, appdata.n_packets);
   pcap_close (pch_struct);
-  g_my_info (_("Capture device stopped or file closed"));
+  g_my_info(_("Capture device stopped or file closed"));
 
   return TRUE;
 }				/* stop_capture */
@@ -348,7 +399,8 @@ get_offline_packet (void)
 {
   static struct pcap_pkthdr *pkt_header = NULL;
   static const u_char *pkt_data = NULL;
-  static struct timeval last_read_time = { 0, 0 }, this_time, diff;
+  static struct timeval last_read_time = { 0, 0 }, this_time;
+  double diffms;
   int result;
 
   if (capture_status == STOP)
@@ -361,7 +413,7 @@ get_offline_packet (void)
 
   if (pkt_data)
   {
-    gettimeofday (&now, NULL);
+    gettimeofday (&appdata.now, NULL);
     packet_acquired( (guint8 *)pkt_data, pkt_header->caplen, pkt_header->len);
   }
 
@@ -378,23 +430,26 @@ get_offline_packet (void)
       this_time.tv_sec = pkt_header->ts.tv_sec;
       this_time.tv_usec = pkt_header->ts.tv_usec;
 
-      diff = substract_times (this_time, last_read_time);
+      diffms = substract_times_ms(&this_time, &last_read_time);
 
       /* diff can be negative when listening to multiple interfaces.
        * In that case the delay is zeroed */
-      if (diff.tv_sec < 0)
+      if (diffms < 0)
         ms_to_next = 0; 
       else 
-        ms_to_next = diff.tv_sec * 1000 + diff.tv_usec / 1000;
-      if (ms_to_next < pref.min_delay)
-          ms_to_next = pref.min_delay;
-      else if (ms_to_next > pref.max_delay)
-          ms_to_next = pref.max_delay;
+        ms_to_next = diffms;
+      if (ms_to_next < appdata.min_delay)
+          ms_to_next = appdata.min_delay;
+      else if (ms_to_next > appdata.max_delay)
+          ms_to_next = appdata.max_delay;
 
       last_read_time = this_time;
       break;
     case -2:
       capture_status = CAP_EOF;
+      /* xml dump if needed */
+      if (appdata.export_file_final)
+        dump_xml(appdata.export_file_final);
       break;
     default:
       ms_to_next=0; /* error or timeout, ignore packet */
@@ -402,6 +457,15 @@ get_offline_packet (void)
   return FALSE;
 }				/* get_offline_packet */
 
+/* cancels the current timer, forcing another packet */
+void force_next_packet(void)
+{
+  if (ms_to_next > 20)
+    {
+      ms_to_next = 0;
+      g_source_remove(capture_source);
+    }
+}
 
 static void
 cap_t_o_destroy (gpointer data)
@@ -419,21 +483,41 @@ cap_t_o_destroy (gpointer data)
 
 /* This function is the gdk callback called when the capture socket holds data */
 static void
-read_packet_live(gpointer dummy, gint source, GdkInputCondition condition)
+gdk_input_callback(gpointer dummy, gint source, GdkInputCondition condition)
+{
+  get_live_packet();
+}
+
+static guint get_live_packet(void)
 {
   struct pcap_pkthdr *pkt_header = NULL;
   const u_char *pkt_data = NULL;
 
-  /* Get next packet */
-  if (pcap_next_ex(pch_struct, &pkt_header, &pkt_data) != 1)
-    return; /* read failed */
+  if (capture_status != PLAY && capture_status != PAUSE )
+    return FALSE; /* stop timer */
 
-  /* Redhat's pkt_header.ts is not a timeval, so I can't
-   * just copy the structures */
-  now.tv_sec = pkt_header->ts.tv_sec;
-  now.tv_usec = pkt_header->ts.tv_usec;
- 
-  if (pkt_data)
-    packet_acquired( (guint8 *)pkt_data, pkt_header->caplen, pkt_header->len);
+  /* Get next packet */
+  if (pcap_next_ex(pch_struct, &pkt_header, &pkt_data) == 1)
+    {
+      /* packet read */
+      
+      /* Redhat's pkt_header.ts is not a timeval, so I can't just copy 
+       * the structures */
+      appdata.now.tv_sec = pkt_header->ts.tv_sec;
+      appdata.now.tv_usec = pkt_header->ts.tv_usec;
+     
+      if (pkt_data)
+        packet_acquired( (guint8 *)pkt_data, pkt_header->caplen, pkt_header->len);
+    }
+  return FALSE;
 }
 
+static void live_timeout(gpointer data)
+{
+  if (capture_status == PLAY)
+    capture_source = g_timeout_add_full (G_PRIORITY_DEFAULT,
+                                         1,
+                                         (GtkFunction) get_live_packet,
+                                         data,
+                                         (GDestroyNotify) live_timeout);
+}
