@@ -63,12 +63,17 @@ size_mode_t;
 
 typedef enum
 {
+  /* Beware! The value given by the option widget must be coherent with
+   * the order of string in glade combo! */
   INST_TOTAL = 0,
-  INST_INBOUND = 1,
-  INST_OUTBOUND = 2,
-  ACCU_TOTAL = 3,
-  ACCU_INBOUND = 4,
-  ACCU_OUTBOUND = 5
+  INST_INBOUND,
+  INST_OUTBOUND,
+  INST_PACKETS,
+  ACCU_TOTAL,
+  ACCU_INBOUND,
+  ACCU_OUTBOUND,
+  ACCU_PACKETS,
+  ACCU_AVG_SIZE,
 }
 node_size_variable_t;
 
@@ -122,11 +127,6 @@ address_t;
 						      G_LOG_LEVEL_CRITICAL, \
 						      format, ##args)
 
-#define IS_OLDER(diff, timeout)        ((diff.tv_sec > timeout/1000) | \
-					    (diff.tv_usec/1000 >= timeout))
-
-
-
 /* Pointer versions of ntohs and ntohl.  Given a pointer to a member of a
  * byte array, returns the value of the two or four bytes at the pointer.
  */
