@@ -20,19 +20,20 @@
 
 typedef struct
 {
-  guint32 src_address;
-  guint32 dst_address;
+  address_t src_address;
+  address_t dst_address;
   guint16 src_port;
   guint16 dst_port;
   gchar *data;
 }
 conversation_t;
 
-void add_conversation (guint32 src_address, guint32 dst_address,
+void add_conversation (address_t * src_address, address_t * dst_address,
 		       guint16 src_port, guint16 dst_port, const gchar * data);
-const gchar *find_conversation (guint32 src_address, guint32 dst_address,
-			  guint16 src_port, guint16 dst_port);
-void delete_conversation_link(guint32 src_address, guint32 dst_address);
+const gchar *find_conversation (address_t * src_address, 
+		       address_t * dst_address, guint16 src_port, guint16 dst_port);
+void delete_conversation_link(address_t * src_address, 
+		       address_t * dst_address);
 void delete_conversations (void);
 
 long active_conversations(void);
