@@ -17,10 +17,15 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <glib.h>
 #include <gtk/gtk.h>
 #include "datastructs.h"
-#include "globals.h"
+#include "appdata.h"
+#include "util.h"
 
 #define LINESIZE 1024
 
@@ -104,9 +109,9 @@ protohash_set(gchar *protoname, GdkColor protocolor)
                        g_memdup(&item, sizeof(ColorHashItem)));
     }
 
-  /* Without protocol, or if we want also registered colors in the cycle
-    * list, we add the color to the cycle list. Cycle colors aren't preferred */
-   if (!protoname || !*protoname || pref.cycle)
+  /* Without protocols defined we add the color to the cycle list. Cycle colors 
+     aren't preferred */
+   if (!protoname || !*protoname)
      {
        item.preferred = FALSE;
        cycle_color_list = g_list_prepend(cycle_color_list, 
