@@ -20,7 +20,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include "globals.h"
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "appdata.h"
 #include <ctype.h>
 #include <string.h>
 #ifdef HAVE_ARPA_INET_H
@@ -32,8 +36,10 @@
 #include "protocols.h"
 #include "conversations.h"
 #include "datastructs.h"
+#include "preferences.h"
 #include "node.h"
 #include "links.h"
+#include "names.h"
 
 #define TCP_FTP 21
 #define TCP_NETBIOS_SSN 139
@@ -116,7 +122,9 @@ static void get_ieee802_5_type (decode_proto_t *dp);
 static void get_eth_II (decode_proto_t *dp, etype_t etype);
 static void get_eth_802_3 (decode_proto_t *dp, ethhdrtype_t ethhdr_type);
 static void get_radiotap (decode_proto_t *dp);
+#if defined(DLT_PPI)  
 static void get_ppi (decode_proto_t *dp);
+#endif
 static void get_wlan (decode_proto_t *dp);
 static void get_linux_sll (decode_proto_t *dp);
 
@@ -141,7 +149,7 @@ static void append_etype_prot (decode_proto_t *dp, etype_t etype);
 typedef struct linktype_data_tag
 {
   const gchar *lt_desc; /* linktype description */
-  int dlt_linktype; /* pcap link type (DLT_xxxx defines) */
+  unsigned int dlt_linktype; /* pcap link type (DLT_xxxx defines) */
   apemode_t l2_idtype;   /* link level address slot in node_id_t */
   get_fun fun;  /* linktype base decoder function */
     
@@ -165,8 +173,10 @@ static linktype_data_t linktypes[] = {
  {"WLAN",   DLT_IEEE802_11,    LINK6,   get_wlan }, 
  /* Wireless with radiotap header */
  {"WLAN+RTAP",  DLT_IEEE802_11_RADIO, LINK6, get_radiotap }, 
+#if defined(DLT_PPI)  
  {"PPI",  DLT_PPI, LINK6, get_ppi }, /* PPI encapsulation */
- {NULL,   0, 0 } /* terminating entry, must be last */
+#endif  
+ {NULL,   0, 0, NULL } /* terminating entry, must be last */
 };
 
 /* ------------------------------------------------------------
@@ -174,7 +184,7 @@ static linktype_data_t linktypes[] = {
  * ------------------------------------------------------------*/
 
 /* Sets the correct linktype entry. Returns false if not found */
-gboolean setup_link_type(int linktype)
+gboolean setup_link_type(unsigned int linktype)
 {
   int i;
 
@@ -269,7 +279,7 @@ void packet_acquired(guint8 * raw_packet, guint raw_size, guint pkt_size)
   g_assert(packet);
   
   packet->size = pkt_size;
-  packet->timestamp = now;
+  packet->timestamp = appdata.now;
   packet->ref_count = 0;
 
   /* Get the protocol tree */
@@ -282,8 +292,8 @@ void packet_acquired(guint8 * raw_packet, guint raw_size, guint pkt_size)
     }
   packet->prot_desc = decp.pr;
 
-  n_packets++;
-  total_mem_packets++;
+  appdata.n_packets++;
+  appdata.total_mem_packets++;
 
   /* Add this packet information to the src and dst nodes. If they
    * don't exist, create them */
@@ -291,9 +301,20 @@ void packet_acquired(guint8 * raw_packet, guint raw_size, guint pkt_size)
   add_node_packet (raw_packet, raw_size, packet, &decp.dst_node_id, INBOUND);
 
   /* And now we update link traffic information for this packet */
-  link_id.src = decp.src_node_id;
-  link_id.dst = decp.dst_node_id;
-  links_catalog_add_packet(&link_id, packet);
+  if (node_id_compare (&decp.src_node_id, &decp.dst_node_id) < 1)
+    {
+      /* src id <= dst id, direct packet */
+      link_id.src = decp.src_node_id;
+      link_id.dst = decp.dst_node_id;
+      links_catalog_add_packet(&link_id, packet, OUTBOUND);
+    } 
+  else
+    {
+      /* src id <= dst id, inverse packet */
+      link_id.src = decp.dst_node_id;
+      link_id.dst = decp.src_node_id;
+      links_catalog_add_packet(&link_id, packet, INBOUND);
+    }
 
   /* finally, update global protocol stats */
   protocol_summary_add_packet(packet);
@@ -573,6 +594,7 @@ static void get_radiotap(decode_proto_t *dp)
   get_wlan(dp);
 }
 
+#if defined(DLT_PPI)  
 /* handles PPI (Per Packet Incapsulation) header */
 static void get_ppi(decode_proto_t *dp)
 {
@@ -619,6 +641,7 @@ static void get_ppi(decode_proto_t *dp)
     }
   pph_lkentry->fun(dp);
 }
+#endif
 
 static void decode_wlan_mgmt(decode_proto_t *dp, uint8_t subtype)
 {
@@ -656,7 +679,6 @@ static void decode_wlan_mgmt(decode_proto_t *dp, uint8_t subtype)
 /* ieee802.11 wlans */
 static void get_wlan(decode_proto_t *dp)
 {
-  uint16_t fc;
   uint8_t type;
   uint8_t subtype;
   uint8_t wep;
@@ -949,7 +971,7 @@ get_ip (decode_proto_t *dp)
       fragment_offset = pntohs (dp->cur_packet + 6);
       fragment_offset &= 0x0fff;
 
-      if (pref.mode !=  LINK6)
+      if (appdata.mode !=  LINK6)
         {
           /* we want node higher level node ids */
           dp->dst_node_id.node_type = IP;
@@ -974,7 +996,7 @@ get_ip (decode_proto_t *dp)
       ip_type = dp->cur_packet[6];
       fragment_offset = 0;
 
-      if (pref.mode !=  LINK6)
+      if (appdata.mode !=  LINK6)
         {
           /* we want higher level node ids */
           dp->dst_node_id.node_type = IP;
@@ -1219,7 +1241,7 @@ get_tcp (decode_proto_t *dp)
   dp->global_src_port = src_port = pntohs (dp->cur_packet);
   dp->global_dst_port = dst_port = pntohs (dp->cur_packet + 2);
 
-  if (pref.mode ==  TCP)
+  if (appdata.mode ==  TCP)
     {
       /* tcp mode node ids have both addr and port - to work we need 
        * to already have an IP node id */
@@ -1313,7 +1335,7 @@ get_udp (decode_proto_t *dp)
   dp->global_src_port = src_port = pntohs (dp->cur_packet);
   dp->global_dst_port = dst_port = pntohs (dp->cur_packet + 2);
 
-  if (pref.mode ==  TCP)
+  if (appdata.mode ==  TCP)
     {
       /* tcp/udp mode node ids have both addr and port - to work we need 
        * to already have an IP node id */
@@ -1404,8 +1426,9 @@ get_rpc (decode_proto_t *dp, gboolean is_udp)
       /* RPC_REPLYs don't carry an rpc program tag */
       /* TODO In order to be able to dissect what is it's 
        * protocol I'd have to keep track of who sent
-       * which call */
-      if (!(rpc_prot = find_conversation (&dp->global_dst_address, 0,
+       * which call - we use the same addr for both sides */
+      if (!(rpc_prot = find_conversation (&dp->global_dst_address, 
+                                          &dp->global_dst_address,
 					  dp->global_dst_port, 0)))
 	return FALSE;
       decode_proto_add(dp, "ONC-RPC");
@@ -1464,10 +1487,11 @@ get_rpc (decode_proto_t *dp, gboolean is_udp)
           break;
 	}
 
-      /* Search for an already existing conversation, if not, create one */
+      /* Search for an already existing conversation, if not, create one 
+         using the same address for both src and dst */
       g_assert(rpc_prot);
-      if (!find_conversation (&dp->global_src_address, 0, dp->global_src_port, 0))
-	add_conversation (&dp->global_src_address, 0,
+      if (!find_conversation (&dp->global_src_address, &dp->global_src_address, dp->global_src_port, 0))
+	add_conversation (&dp->global_src_address, &dp->global_src_address,
 			  dp->global_src_port, 0, rpc_prot);
 
       decode_proto_add(dp, "ONC-RPC");
