@@ -25,7 +25,7 @@
 #include "node_id.h"
 
 gboolean has_linklevel(void); /* true if current device captures l2 data */ 
-gboolean setup_link_type(int linktype);
+gboolean setup_link_type(unsigned int linktype);
 void packet_acquired(guint8 * packet, guint raw_size, guint pkt_size);
 
 #endif
