@@ -17,7 +17,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include "globals.h"
+#include "appdata.h"
 
 
 
@@ -31,5 +31,5 @@ void destroying_idle (gpointer data);
 void set_statusbar_msg (gchar * str);
 void delete_gui_protocols (void);
 void ask_reposition(gboolean refresh_font); /* request diagram relayout */
-void change_refresh_period(guint32 newperiod); 
 void dump_stats(guint32 diff_msecs);
+void timeout_changed(void);
