@@ -23,13 +23,14 @@
 
 #include <math.h>
 #include <time.h>
-#include "globals.h"
+#include "appdata.h"
 #include "info_windows.h"
 #include "diagram.h"
 #include "node.h"
 #include "datastructs.h"
 #include "protocols.h"
 #include "capture.h"
+#include "preferences.h"
 #include "prot_types.h"
 #include "ui_utils.h"
 #include "node_windows.h"
@@ -108,11 +109,11 @@ create_prot_info_window (protocol_t * protocol)
 			    protocol->name, prot_info_compare)))
     {
       xml_info_window =
-	glade_xml_new (pref.glade_file, "prot_info", NULL);
+	glade_xml_new (appdata.glade_file, "prot_info", NULL);
       if (!xml_info_window)
 	{
 	  g_error (_("We could not load the interface! (%s)"),
-		   pref.glade_file);
+		   appdata.glade_file);
 	  return;
 	}
       glade_xml_signal_autoconnect (xml_info_window);
@@ -276,7 +277,7 @@ protocols_table_compare (GtkTreeModel * gs, GtkTreeIter * a, GtkTreeIter * b,
 {
   gint ret = 0;
   gdouble t1, t2;
-  struct timeval time1, time2, diff;
+  gdouble diffms;
   gint idcol;
   GtkSortType order;
 
@@ -330,12 +331,11 @@ protocols_table_compare (GtkTreeModel * gs, GtkTreeIter * a, GtkTreeIter * b,
 	ret = 1;
       break;
     case PROTO_COLUMN_LASTHEARD:
-      time1 = prot1->rowstats.last_time;
-      time2 = prot2->rowstats.last_time;
-      diff = substract_times (time1, time2);
-      if ((diff.tv_sec == 0) && (diff.tv_usec == 0))
+      diffms = substract_times_ms(&prot1->rowstats.last_time, 
+                                  &prot2->rowstats.last_time);
+      if (diffms == 0)
 	ret = 0;
-      else if ((diff.tv_sec < 0) || (diff.tv_usec < 0))
+      else if (diffms < 0)
 	ret = -1;
       else
 	ret = 1;
@@ -470,7 +470,6 @@ static void update_protocols_table(GtkWidget *window, const protostack_t *pstk)
 {
   GtkListStore *gs;
   GList *item;
-  gchar *str;
   gboolean res;
   GtkTreeIter it;
 
@@ -561,14 +560,13 @@ update_protocols_window (void)
 {
   GtkWidget *window;
   GtkTreeView *gv;
-  GtkListStore *gs = NULL;
 
-  window = glade_xml_get_widget (xml, "protocols_window");
+  window = glade_xml_get_widget (appdata.xml, "protocols_window");
   gv = retrieve_treeview(window);
   if (!gv)
     {
       /* register gv */
-      gv = GTK_TREE_VIEW (glade_xml_get_widget (xml, "prot_clist"));
+      gv = GTK_TREE_VIEW (glade_xml_get_widget (appdata.xml, "prot_clist"));
       if (!gv)
         {
           g_critical("can't find prot_clist");
@@ -583,7 +581,7 @@ update_protocols_window (void)
 void
 toggle_protocols_window (void)
 {
-  GtkWidget *protocols_check = glade_xml_get_widget (xml, "protocols_check");
+  GtkWidget *protocols_check = glade_xml_get_widget (appdata.xml, "protocols_check");
   if (!protocols_check)
     return;
   gtk_menu_item_activate (GTK_MENU_ITEM (protocols_check));
@@ -599,7 +597,7 @@ on_delete_protocol_window (GtkWidget * wdg, GdkEvent * evt, gpointer ud)
 void
 on_protocols_check_activate (GtkCheckMenuItem * menuitem, gpointer user_data)
 {
-  GtkWidget *protocols_window = glade_xml_get_widget (xml, "protocols_window");
+  GtkWidget *protocols_window = glade_xml_get_widget (appdata.xml, "protocols_window");
   if (!protocols_window)
     return;
   if (gtk_check_menu_item_get_active (menuitem))
@@ -612,7 +610,7 @@ on_protocols_check_activate (GtkCheckMenuItem * menuitem, gpointer user_data)
     {
       /* retrieve view and model (store) */
       GtkListStore *gs;
-      GtkTreeView *gv = GTK_TREE_VIEW(glade_xml_get_widget(xml, "prot_clist"));
+      GtkTreeView *gv = GTK_TREE_VIEW(glade_xml_get_widget(appdata.xml, "prot_clist"));
       if (gv)
         {
           gs = GTK_LIST_STORE (gtk_tree_view_get_model (gv));
@@ -685,7 +683,7 @@ update_info_windows (void)
   if (status != PLAY && status != STOP)
     return TRUE;
 
-  gettimeofday (&now, NULL);
+  gettimeofday (&appdata.now, NULL);
 
   update_protocols_window ();
   update_stats_info_windows ();
@@ -720,18 +718,19 @@ update_stats_info_windows (void)
   GList *list_item;
   GtkWidget *window;
   enum status_t status;
-  struct timeval diff;
+  double diffms;
   static struct timeval last_update_time = {
     0, 0
   };
 
   status = get_capture_status();
 
-  diff = substract_times (now, last_update_time);
   /* Update info windows at most twice a second */
+  diffms = substract_times_ms(&appdata.now, &last_update_time);
   if (pref.refresh_period < 500)
-    if (!(IS_OLDER (diff, 500)))
+    if (diffms < 500)
       return;
+
   list_item = stats_info_windows;
   while (list_item)
     {
@@ -759,7 +758,7 @@ update_stats_info_windows (void)
 	}
     }
 
-  last_update_time = now;
+  last_update_time = appdata.now;
 }				/* update_stats_info_windows */
 
 
@@ -776,11 +775,11 @@ stats_info_create(const gchar *idkey, gpointer key)
   GtkTreeView *gv;
 
   xml_info_window =
-    glade_xml_new (pref.glade_file, "node_proto_info", NULL);
+    glade_xml_new (appdata.glade_file, "node_proto_info", NULL);
   if (!xml_info_window)
     {
       g_error (_("We could not load the interface! (%s)"),
-               pref.glade_file);
+               appdata.glade_file);
       return NULL;
     }
   glade_xml_signal_autoconnect (xml_info_window);
@@ -829,23 +828,19 @@ stats_info_create(const gchar *idkey, gpointer key)
 
 
 static void
-stats_info_update(GtkWidget *window, const traffic_stats_t *stats, 
-                  gboolean totals_only)
+stats_info_update(GtkWidget *window, const traffic_stats_t *stats)
 {
   if (!stats)
     {
       update_gtklabel(window, "node_iproto_avg", "X");
       update_gtklabel(window, "node_iproto_accum", "X");
       update_gtklabel(window, "node_iproto_avgsize", "X");
-      if (!totals_only)
-        {
-          update_gtklabel(window, "node_iproto_avg_in", "X");
-          update_gtklabel(window, "node_iproto_avg_out", "X");
-          update_gtklabel(window, "node_iproto_accum_in", "X");
-          update_gtklabel(window, "node_iproto_accum_out", "X");
-          update_gtklabel(window, "node_iproto_avgsize_in", "X");
-          update_gtklabel(window, "node_iproto_avgsize_out", "X");
-        }
+      update_gtklabel(window, "node_iproto_avg_in", "X");
+      update_gtklabel(window, "node_iproto_avg_out", "X");
+      update_gtklabel(window, "node_iproto_accum_in", "X");
+      update_gtklabel(window, "node_iproto_accum_out", "X");
+      update_gtklabel(window, "node_iproto_avgsize_in", "X");
+      update_gtklabel(window, "node_iproto_avgsize_out", "X");
       update_protocols_table(window, NULL);
       gtk_widget_queue_resize (GTK_WIDGET (window));
     }
@@ -861,27 +856,24 @@ stats_info_update(GtkWidget *window, const traffic_stats_t *stats,
       str = traffic_to_str (stats->stats.avg_size, FALSE);
       update_gtklabel(window, "node_iproto_avgsize", str);
       g_free(str);
-      if (!totals_only)
-        {
-          str = traffic_to_str (stats->stats_in.average, TRUE);
-          update_gtklabel(window, "node_iproto_avg_in", str);
-          g_free(str);
-          str = traffic_to_str (stats->stats_out.average, TRUE);
-          update_gtklabel(window, "node_iproto_avg_out", str);
-          g_free(str);
-          str = traffic_to_str (stats->stats_in.accumulated, FALSE);
-          update_gtklabel(window, "node_iproto_accum_in", str);
-          g_free(str);
-          str = traffic_to_str (stats->stats_out.accumulated, FALSE);
-          update_gtklabel(window, "node_iproto_accum_out", str);
-          g_free(str);
-          str = traffic_to_str (stats->stats_in.avg_size, FALSE);
-          update_gtklabel(window, "node_iproto_avgsize_in", str);
-          g_free(str);
-          str = traffic_to_str (stats->stats_out.avg_size, FALSE);
-          update_gtklabel(window, "node_iproto_avgsize_out", str);
-          g_free(str);
-        }
+      str = traffic_to_str (stats->stats_in.average, TRUE);
+      update_gtklabel(window, "node_iproto_avg_in", str);
+      g_free(str);
+      str = traffic_to_str (stats->stats_out.average, TRUE);
+      update_gtklabel(window, "node_iproto_avg_out", str);
+      g_free(str);
+      str = traffic_to_str (stats->stats_in.accumulated, FALSE);
+      update_gtklabel(window, "node_iproto_accum_in", str);
+      g_free(str);
+      str = traffic_to_str (stats->stats_out.accumulated, FALSE);
+      update_gtklabel(window, "node_iproto_accum_out", str);
+      g_free(str);
+      str = traffic_to_str (stats->stats_in.avg_size, FALSE);
+      update_gtklabel(window, "node_iproto_avgsize_in", str);
+      g_free(str);
+      str = traffic_to_str (stats->stats_out.avg_size, FALSE);
+      update_gtklabel(window, "node_iproto_avgsize_out", str);
+      g_free(str);
       /* update protocol table */
       update_protocols_table(window, &stats->stats_protos);
     }
@@ -915,8 +907,6 @@ node_protocols_window_create(const node_id_t * node_id)
 static void
 update_node_protocols_window (GtkWidget *window)
 {
-  GtkListStore *gs;
-  GtkTreeView *gv;
   const node_id_t *node_id;
   const node_t *node;
 
@@ -926,7 +916,7 @@ update_node_protocols_window (GtkWidget *window)
     {
       /* node expired, clear stats */
       update_gtklabel(window, "node_iproto_numeric_name", _("Node timed out"));
-      stats_info_update(window, NULL, FALSE);
+      stats_info_update(window, NULL);
       return;
     }
 
@@ -935,7 +925,7 @@ update_node_protocols_window (GtkWidget *window)
   update_gtklabel(window, "node_iproto_name", node->name->str);
   update_gtklabel(window, "node_iproto_numeric_name", node->numeric_name->str);
   
-  stats_info_update(window, &node->node_stats, FALSE);
+  stats_info_update(window, &node->node_stats);
 }
 
 /****************************************************************************
@@ -981,9 +971,6 @@ link_info_window_create(const link_id_t * link_id)
 static void
 update_link_info_window (GtkWidget *window)
 {
-  GtkListStore *gs;
-  GtkTreeView *gv;
-  GtkWidget *widget;
   const link_id_t *link_id;
   const link_t *link;
   const node_t *node;
@@ -992,9 +979,8 @@ update_link_info_window (GtkWidget *window)
   /* updates column descriptions */
   show_widget(window, "src_label");
   show_widget(window, "dst_label");
-  update_gtklabel(window, "total_label", _("Traffic"));
-  hide_widget(window, "inbound_label");
-  hide_widget(window, "outbound_label");
+  update_gtklabel(window, "inbound_label", _("B->A"));
+  update_gtklabel(window, "outbound_label", _("A->B"));
 
   link_id = g_object_get_data (G_OBJECT (window), "link_id");
   link = links_catalog_find(link_id);
@@ -1003,7 +989,7 @@ update_link_info_window (GtkWidget *window)
       /* node expired, clear stats */
       update_gtklabel(window, "node_iproto_numeric_name", _("Link timed out"));
       update_gtklabel(window, "node_iproto_numeric_name_b", "");
-      stats_info_update(window, NULL, TRUE);
+      stats_info_update(window, NULL);
       return;
     }
 
@@ -1035,5 +1021,5 @@ update_link_info_window (GtkWidget *window)
     update_gtklabel(window, "node_iproto_numeric_name_b", _("Node timed out"));
   }
 
-  stats_info_update(window, &link->link_stats, TRUE);
+  stats_info_update(window, &link->link_stats);
 }
