@@ -28,24 +28,23 @@
 #include <signal.h>
 #include <gnome.h>
 #include <libgnomeui/gnome-client.h>
-#include "globals.h"
+#include "appdata.h"
 #include "ip-cache.h"
 #include "main.h"
 #include "diagram.h"
 #include "preferences.h"
 #include "info_windows.h"
+#include "menus.h"
 #include "capture.h"
 #include "datastructs.h"
 
-#define ETHERAPE_GLADE_FILE "etherape.glade"	/* glade 3 file */
-
 /***************************************************************************
  *
  * local variables
  *
  **************************************************************************/
 static gboolean quiet = FALSE;
-static void (*oldhandler) (int);
+static void (*old_sighup_handler) (int);
 
 /***************************************************************************
  *
@@ -55,13 +54,16 @@ static void (*oldhandler) (int);
 static void free_static_data(void);
 static void set_debug_level (void);
 static void session_die (GnomeClient * client, gpointer client_data);
-static gint
-save_session (GnomeClient * client, gint phase, GnomeSaveStyle save_style,
-	      gint is_shutdown, GnomeInteractStyle interact_style,
-	      gint is_fast, gpointer client_data);
-static void
-log_handler (gchar * log_domain,
-	     GLogLevelFlags mask, const gchar * message, gpointer user_data);
+static gint save_session (GnomeClient * client, gint phase, 
+                          GnomeSaveStyle save_style, gint is_shutdown, 
+                          GnomeInteractStyle interact_style, gint is_fast, 
+                          gpointer client_data);
+static void log_handler (gchar * log_domain, GLogLevelFlags mask, 
+                         const gchar * message, gpointer user_data);
+
+/* signal handling */
+static void install_handlers(void);
+static void signal_export(int signum);
 
 /***************************************************************************
  *
@@ -77,10 +79,13 @@ main (int argc, char *argv[])
   gchar *cl_filter = NULL;
   gchar *cl_interface = NULL;
   gchar *cl_input_file = NULL;
+  gchar *export_file_final = NULL;
+  gchar *export_file_signal = NULL;
   gboolean cl_numeric = FALSE;
   glong midelay = 0;
   glong madelay = G_MAXLONG;
   gchar *version;
+  gchar *cl_glade_file = NULL;
   poptContext poptcon;
 
   struct poptOption optionsTable[] = {
@@ -92,9 +97,13 @@ main (int argc, char *argv[])
      N_("set capture filter"), N_("<capture filter>")},
     {"interface", 'i', POPT_ARG_STRING, &cl_interface, 0,
      N_("set interface to listen to"), N_("<interface name>")},
+    {"final-export", 0, POPT_ARG_STRING, &export_file_final, 0,
+     N_("export to named file at end of replay"), N_("<file to export to>")},
+    {"signal-export", 0, POPT_ARG_STRING, &export_file_signal, 0,
+     N_("export to named file on receiving USR1"), N_("<file to export to>")},
     {"stationary", 's', POPT_ARG_NONE, &(pref.stationary), 0,  
      N_("don't move nodes around (deprecated)"), NULL}, 
-    {"node-limit", 'l', POPT_ARG_INT, &(pref.node_limit), 0,
+    {"node-limit", 'l', POPT_ARG_INT, &(appdata.node_limit), 0,
      N_("limits nodes displayed"), N_("<number of nodes>")},
     {"mode", 'm', POPT_ARG_STRING, &mode_string, 0,
      N_("mode of operation"), N_("<link|ip|tcp>")},
@@ -108,13 +117,12 @@ main (int argc, char *argv[])
     {"max-delay", 0, POPT_ARG_LONG, &madelay,  0,
      N_("maximum packet delay in ms for reading capture files [cli only]"),
       N_("<delay>")},
-    {"glade-file", 0, POPT_ARG_STRING, &(pref.glade_file), 0,
+    {"glade-file", 0, POPT_ARG_STRING, &(cl_glade_file), 0,
      N_("uses the named libglade file for widgets"), N_("<glade file>")},
 
-    POPT_AUTOHELP {NULL, 0, 0, NULL, 0}
+    POPT_AUTOHELP {NULL, 0, 0, NULL, 0, NULL, NULL}
   };
 
-
 #ifdef ENABLE_NLS
   bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
   bind_textdomain_codeset(PACKAGE, "UTF-8"); /* force UTF-8 conversion */
@@ -138,6 +146,7 @@ main (int argc, char *argv[])
 		      GNOME_PARAM_POPT_TABLE, optionsTable, GNOME_PARAM_NONE);
   g_free(version);
 
+  appdata_init(&appdata);
 
   /* We obtain application parameters 
    * First, absolute defaults
@@ -145,10 +154,10 @@ main (int argc, char *argv[])
    * Third, whatever given in the command line */
   init_config(&pref);
 
-  set_debug_level ();
+  set_debug_level();
 
   /* Config file */
-  load_config ("/Etherape/");
+  load_config();
 
   /* Command line */
   cl_numeric = !pref.name_res;
@@ -158,33 +167,47 @@ main (int argc, char *argv[])
 
   if (cl_interface)
     {
-      if (pref.interface)
-	g_free (pref.interface);
-      pref.interface = g_strdup (cl_interface);
+      if (appdata.interface)
+	g_free (appdata.interface);
+      appdata.interface = g_strdup (cl_interface);
     }
 
+  if (export_file_final)
+    {
+      if (appdata.export_file_final)
+	g_free (appdata.export_file_final);
+      appdata.export_file_final = g_strdup (export_file_final);
+    }
+  if (export_file_signal)
+    {
+      if (appdata.export_file_signal)
+	g_free (appdata.export_file_signal);
+      appdata.export_file_signal = g_strdup (export_file_signal);
+    }
+
+  pref.name_res = !cl_numeric;
+
   if (cl_input_file)
     {
-      if (pref.input_file)
-	g_free (pref.input_file);
-      pref.input_file = g_strdup (cl_input_file);
+      if (appdata.input_file)
+	g_free (appdata.input_file);
+      appdata.input_file = g_strdup (cl_input_file);
     }
-  pref.name_res = !cl_numeric;
 
   /* Find mode of operation */
   if (mode_string)
     {
       if (strstr (mode_string, "link"))
-	pref.mode = LINK6;
-      else if (strstr (mode_string, "ip or ip6"))
-	pref.mode = IP;
+	appdata.mode = LINK6;
+      else if (strstr (mode_string, "ip"))
+	appdata.mode = IP;
       else if (strstr (mode_string, "tcp"))
-	pref.mode = TCP;
+	appdata.mode = TCP;
       else
 	g_warning (_
 		   ("Unrecognized mode. Do etherape --help for a list of modes"));
       g_free(pref.filter);
-      pref.filter = get_default_filter(pref.mode);
+      pref.filter = get_default_filter(appdata.mode);
     }
 
   if (cl_filter)
@@ -196,52 +219,40 @@ main (int argc, char *argv[])
 
   if (midelay >= 0 && midelay <= G_MAXLONG)
     {
-       pref.min_delay = midelay;
-       g_message("Minimum delay set to %lu ms", pref.min_delay);
+       appdata.min_delay = midelay;
+       if (appdata.min_delay != 0)
+         g_message("Minimum delay set to %lu ms", appdata.min_delay);
     }
   else
       g_message("Invalid minimum delay %ld, ignored", midelay);
   
   if (madelay >= 0 && madelay <= G_MAXLONG)
     {
-      if (madelay < pref.min_delay)
+      if (madelay < appdata.min_delay)
         {
           g_message("Maximum delay must be less of minimum delay");
-          pref.max_delay = pref.min_delay;
+          appdata.max_delay = appdata.min_delay;
         }
       else
-        pref.max_delay = madelay;
-      g_message("Maximum delay set to %lu ms", pref.max_delay);
+        appdata.max_delay = madelay;
+      if (appdata.max_delay != G_MAXLONG)
+        g_message("Maximum delay set to %lu ms", appdata.max_delay);
     }
   else
       g_message("Invalid maximum delay %ld, ignored", madelay);
   
   /* Glade */
-
   glade_gnome_init ();
   glade_require("gnome");
   glade_require("canvas");
-
-  if (!pref.glade_file)
-    pref.glade_file = GLADEDIR "/" ETHERAPE_GLADE_FILE;
-
-  xml = glade_xml_new (pref.glade_file, NULL, NULL);
-  if (!xml)
-    {
-      g_error (_("We could not load glade interface file! (%s)"),
-	       pref.glade_file);
-      return 1;
-    }
-  glade_xml_signal_autoconnect (xml);
-
-  app1 = glade_xml_get_widget (xml, "app1");
-  statusbar = GTK_STATUSBAR(glade_xml_get_widget (xml, "statusbar1"));
+  if (!appdata_init_glade(cl_glade_file))
+    return 1;
 
   /* prepare decoders */
   services_init();
   
   /* Sets controls to the values of variables and connects signals */
-  init_diagram (xml);
+  init_diagram (appdata.xml);
 
   /* Session handling */
   client = gnome_master_client ();
@@ -249,28 +260,16 @@ main (int argc, char *argv[])
 		    GTK_SIGNAL_FUNC (save_session), argv[0]);
   g_signal_connect (G_OBJECT (client), "die",
 		    GTK_SIGNAL_FUNC (session_die), NULL);
-  gtk_widget_show (app1);
+  gtk_widget_show (appdata.app1);
 
-  /* 
-   * Signal handling
-   * Catch SIGINT and SIGTERM and, if we get either of them, clean up
-   * and exit.
-   * XXX - deal with signal semantics on various platforms.  Or just
-   * use "sigaction()" and be done with it?
-   */
-  signal (SIGTERM, cleanup);
-  signal (SIGINT, cleanup);
-#if !defined(WIN32)
-  if ((oldhandler = signal (SIGHUP, cleanup)) != SIG_DFL)	/* Play nice with nohup */
-    signal (SIGHUP, oldhandler);
-#endif
+  install_handlers();
 
   /* With this we force an update of the diagram every x ms 
    * Data in the diagram is updated, and then the canvas redraws itself when
    * the gtk loop is idle. If the CPU can't handle the set refresh_period,
    * then it will just do a best effort */
 
-  widget = glade_xml_get_widget (xml, "canvas1");
+  widget = glade_xml_get_widget (appdata.xml, "canvas1");
   destroying_idle (widget);
 
   /* This other timeout makes sure that the info windows are updated */
@@ -306,28 +305,28 @@ set_debug_level (void)
   const gchar *env_debug;
   env_debug = g_getenv("APE_DEBUG");
 
-  pref.debug_mask = (G_LOG_LEVEL_MASK & ~(G_LOG_LEVEL_DEBUG | G_LOG_LEVEL_INFO));
+  appdata.debug_mask = (G_LOG_LEVEL_MASK & ~(G_LOG_LEVEL_DEBUG | G_LOG_LEVEL_INFO));
 
   if (env_debug)
     {
       if (!g_ascii_strcasecmp(env_debug, "INFO"))
-	pref.debug_mask = (G_LOG_LEVEL_MASK & ~G_LOG_LEVEL_DEBUG);
+	appdata.debug_mask = (G_LOG_LEVEL_MASK & ~G_LOG_LEVEL_DEBUG);
       else if (!g_ascii_strcasecmp(env_debug, "DEBUG"))
-	pref.debug_mask = G_LOG_LEVEL_MASK;
+	appdata.debug_mask = G_LOG_LEVEL_MASK;
     }
 
   if (quiet)
-    pref.debug_mask = 0;
+    appdata.debug_mask = 0;
 
   g_log_set_handler (NULL, G_LOG_LEVEL_MASK, (GLogFunc) log_handler, NULL);
-  g_my_debug ("debug_mask %d", pref.debug_mask);
+  g_my_debug ("debug_mask %d", appdata.debug_mask);
 }
 
 static void
 log_handler (gchar * log_domain,
 	     GLogLevelFlags mask, const gchar * message, gpointer user_data)
 {
-  if (mask & pref.debug_mask)
+  if (mask & appdata.debug_mask)
     g_log_default_handler ("EtherApe", mask, message, user_data);
 }
 
@@ -372,15 +371,48 @@ save_session (GnomeClient * client, gint phase, GnomeSaveStyle save_style,
 }				/* save_session */
 
 
+/***************************************************************************
+ *
+ * signal handling
+ *
+ **************************************************************************/
+
+/* installs signal handlers */
+static void install_handlers(void)
+{
+  /* 
+   * Signal handling
+   * Catch SIGINT and SIGTERM and, if we get either of them, clean up
+   * and exit.
+   * XXX - deal with signal semantics on various platforms.  Or just
+   * use "sigaction()" and be done with it?
+   */
+  if (signal(SIGTERM, cleanup) == SIG_IGN)
+     signal(SIGTERM, SIG_IGN);
+  if (signal(SIGINT, cleanup) == SIG_IGN)
+     signal(SIGINT, SIG_IGN);
+#if !defined(WIN32)
+  if ((old_sighup_handler = signal (SIGHUP, cleanup)) != SIG_DFL)	/* Play nice with nohup */
+    signal (SIGHUP, old_sighup_handler);
+#endif
+  if (signal(SIGUSR1, signal_export) == SIG_IGN)
+     signal(SIGUSR1, SIG_IGN);
+}
+
 /*
  * Quit the program.
  * Makes sure that the capture device is closed, or else we might
  * be leaving it in promiscuous mode
  */
-void
-cleanup (int signum)
+void cleanup(int signum)
 {
   cleanup_capture ();
   free_static_data();
   gtk_exit (0);
 }
+
+/* activates a flag requesting an xml dump */
+static void signal_export(int signum)
+{
+  appdata.request_dump = TRUE;
+}
