@@ -17,17 +17,22 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <netinet/in.h>
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
-#include "globals.h"
+#include "appdata.h"
 #include "names.h"
 #include "dns.h"
 #include "eth_resolv.h"
 #include "names_netbios.h"
 #include "protocols.h"
 #include "datastructs.h"
+#include "preferences.h"
 #include "util.h"
 
 typedef struct
@@ -264,7 +269,6 @@ static gboolean get_linux_sll_name (name_add_t *nt)
 static gboolean eth_name_common(apemode_t ethmode, name_add_t *nt)
 {
   const gchar *numeric, *solved;
-  gboolean found_in_ethers = FALSE;
 
   if (nt->dir == INBOUND)
     fill_node_id(&nt->node_id, ethmode, nt, ethmode, 0, 0);
@@ -404,7 +408,7 @@ static gboolean get_tcp_name (name_add_t *nt)
   guint8 tcp_len;
 
   /* tcp names are useful only if someone uses them ... */
-  if (pref.mode == TCP)
+  if (appdata.mode == TCP)
     {
       gchar *numeric_name, *resolved_name;
       int type = nt->node_id.addr.tcp4.host.type;
