@@ -17,7 +17,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include "globals.h"
+#include "appdata.h"
 #include "node.h"
 
 void get_packet_names (protostack_t *pstk,
