@@ -29,7 +29,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-#include "globals.h"
+#include "appdata.h"
 #include <glib.h>
 
 
