@@ -23,6 +23,7 @@
 
 #include <math.h>
 #include "node_windows.h"
+#include "info_windows.h"
 #include "ui_utils.h"
 #include "node.h"
 
@@ -43,14 +44,13 @@ static GtkWidget *nodes_wnd = NULL;	       /* Ptr to nodes window */
 static GtkCheckMenuItem *nodes_check = NULL;   /* Ptr to nodes menu */
 
 /* private functions */
-static void init_all_nodes(GtkWidget *wnd);
 static void nodes_table_clear(GtkWidget *window);
 static void nodes_table_update(GtkWidget *window);
 
 void nodes_wnd_show(void)
 {
-  nodes_wnd = glade_xml_get_widget (xml, "nodes_wnd");
-  nodes_check = GTK_CHECK_MENU_ITEM(glade_xml_get_widget (xml, "nodes_check"));
+  nodes_wnd = glade_xml_get_widget (appdata.xml, "nodes_wnd");
+  nodes_check = GTK_CHECK_MENU_ITEM(glade_xml_get_widget (appdata.xml, "nodes_check"));
 
   if (DEBUG_ENABLED)
     {
@@ -104,7 +104,7 @@ nodes_table_compare (GtkTreeModel * gls, GtkTreeIter * a, GtkTreeIter * b,
 {
   gint ret = 0;
   gdouble t1, t2;
-  struct timeval time1, time2, diff;
+  double diffms;
   const node_id_t *nodeid1, *nodeid2;
   const node_t *node1, *node2;
 
@@ -164,12 +164,11 @@ nodes_table_compare (GtkTreeModel * gls, GtkTreeIter * a, GtkTreeIter * b,
 	ret = 1;
       break;
     case NODES_COLUMN_LASTHEARD:
-      time1 = node1->node_stats.stats.last_time;
-      time2 = node2->node_stats.stats.last_time;
-      diff = substract_times (time1, time2);
-      if ((diff.tv_sec == 0) && (diff.tv_usec == 0))
+      diffms = substract_times_ms(&node1->node_stats.stats.last_time,
+                                  &node2->node_stats.stats.last_time);
+      if (diffms == 0)
 	ret = 0;
-      else if ((diff.tv_sec < 0) || (diff.tv_usec < 0))
+      else if (diffms < 0)
 	ret = -1;
       else
 	ret = 1;
@@ -193,14 +192,13 @@ static GtkListStore *nodes_table_create(GtkWidget *window)
   GtkTreeView *gv;
   GtkListStore *gls;
   GtkTreeModel *sort_model;
-  GtkTreeViewColumn *gc;
   int i;
 
   /* get the treeview */
   gv = retrieve_treeview(window);
   if (!gv)
     {
-      gv = GTK_TREE_VIEW (glade_xml_get_widget (xml, "nodes_table"));
+      gv = GTK_TREE_VIEW (glade_xml_get_widget (appdata.xml, "nodes_table"));
       if (!gv)
         {
           g_critical("can't find nodes_table");
@@ -413,6 +411,14 @@ void on_nodes_check_toggled(GtkCheckMenuItem *checkmenuitem,  gpointer data)
     nodes_wnd_hide();
 }
 
+void on_nodes_toolbar_button_clicked(void)
+{
+  GtkWidget *nodes_check = glade_xml_get_widget (appdata.xml, "nodes_check");
+  if (!nodes_check)
+    return;
+  gtk_menu_item_activate (GTK_MENU_ITEM (nodes_check));
+}
+
 /* double click on row */
 void on_nodes_table_row_activated(GtkTreeView *gv,
                                   GtkTreePath *sorted_path,
