@@ -122,6 +122,7 @@ void init_config(struct pref_struct *p)
   p->text_color=NULL;
   p->fontname=NULL;
   p->colors=NULL;
+  p->center_node = NULL;
 
   p->averaging_time=3000;
 }
@@ -163,6 +164,9 @@ void set_default_config(struct pref_struct *p)
                            " ", 0);
   p->colors = protohash_compact(p->colors);
   protohash_read_prefvect(p->colors);
+
+  g_free(p->center_node);
+  p->center_node = g_strdup("");
 }
 
 /* loads configuration from .gnome/Etherape */
@@ -196,6 +200,7 @@ void load_config(void)
   read_string_config(&pref.filter, gkey, "filter");
   read_string_config(&pref.fontname, gkey, "fontname");
   read_string_config(&pref.text_color, gkey, "text_color");
+  read_string_config(&pref.center_node, gkey, "center_node");
 
   read_boolean_config(&pref.diagram_only, gkey, "diagram_only");
   read_boolean_config(&pref.group_unk, gkey, "group_unk");
@@ -283,6 +288,7 @@ void save_config(void)
   g_key_file_set_string(gkey, pref_group, "filter", pref.filter);
   g_key_file_set_string(gkey, pref_group, "fontname", pref.fontname);
   g_key_file_set_string(gkey, pref_group, "text_color", pref.text_color);
+  g_key_file_set_string(gkey, pref_group, "center_node", pref.center_node);
 
   tmpstr = g_strjoinv(" ", pref.colors);
   g_key_file_set_string(gkey, pref_group, "colors", tmpstr);
@@ -326,6 +332,7 @@ duplicate_config(const struct pref_struct *src)
   t->text_color = NULL;
   t->fontname = NULL;
   t->colors = NULL;
+  t->center_node = NULL;
   copy_config(t, src);
 
   return t;
@@ -340,6 +347,8 @@ void free_config(struct pref_struct *t)
   t->text_color=NULL;
   g_free(t->fontname);
   t->fontname=NULL;
+  g_free(t->center_node);
+  t->center_node=NULL;
 
   g_strfreev(t->colors);
   t->colors = NULL;
@@ -366,6 +375,7 @@ void copy_config(struct pref_struct *tgt, const struct pref_struct *src)
   tgt->filter=g_strdup(src->filter);
   tgt->text_color=g_strdup(src->text_color);
   tgt->fontname=g_strdup(src->fontname);
+  tgt->center_node=g_strdup(src->center_node);
   tgt->stack_level = src->stack_level;
   tgt->colors = g_strdupv(src->colors);
 
