@@ -49,14 +49,18 @@
 #ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
+#ifdef HAVE_INET_NTOP
+#include <arpa/inet.h>
+#endif
 #ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
 #elif !defined(INET6_ADDRSTRLEN)
 #define INET6_ADDRSTRLEN        46
 #endif
 #include <pwd.h>
+#include <locale.h>
 
-#include "globals.h"
+#include "appdata.h"
 #include "util.h"
 
 #include <pcap.h> /*JTC*/
@@ -308,6 +312,8 @@ ether_to_str (const guint8 * ad)
  */
 const gchar *ipv6_to_str (const guint8 *ad)
 {
+  if (!ad)
+    return "<null addr>";
 #ifdef HAVE_INET_NTOP
   static char buf[INET6_ADDRSTRLEN];
   if (!inet_ntop(AF_INET6, ad, buf, sizeof(buf))) 
@@ -359,6 +365,8 @@ const gchar *ipv6_to_str (const guint8 *ad)
 const gchar *
 address_to_str (const address_t * ad)
 {
+  if (!ad)
+    return "<null addr>";
   switch (ad->type)
     {
     case AF_INET:
@@ -373,6 +381,8 @@ address_to_str (const address_t * ad)
 const gchar *
 type_to_str (const address_t * ad)
 {
+  if (!ad)
+    return "<null addr>";
   switch (ad->type)
     {
     case AF_INET:
@@ -384,4 +394,45 @@ type_to_str (const address_t * ad)
     }
 }				/* type_to_str */
 
+/************************************************
+ *
+ * xml helpers 
+ *
+ *************************************************/
 
+/* returns a new string containing the named tag */
+gchar *xmltag(const gchar *name, const gchar *fmt, ...)
+{
+  gchar *msg;
+  gchar *xml;
+  va_list ap;
+  va_start(ap, fmt);
+  msg = g_strdup_vprintf(fmt, ap);
+  va_end(ap);
+  xml = g_strdup_printf("<%s>%s</%s>\n", name, msg, name);
+  g_free(msg);
+  return xml;
+}
+
+
+/************************************************
+ *
+ * compatibility functions for CENTOS5 and RHEL5
+ *
+ *************************************************/
+#if !defined(HAVE_G_QUEUE_INIT)
+
+void compat_g_queue_init(GQueue *gq)
+{
+  g_assert(gq != NULL);
+  gq->head = NULL;
+  gq->tail = NULL;
+  gq->length = 0;
+}
+
+gchar *compat_gdk_color_to_string(const GdkColor *color)
+{
+  g_assert(color != NULL);
+  return g_strdup_printf("#%4.4x%4.4x%4.4x", color->red, color->green, color->blue);
+}
+#endif 
